# emdapiglobalatlasservice.GlobalAtlasServicesApi

All URIs are relative to *http://api.emd.dk*

Method | HTTP request | Description
------------- | ------------- | -------------
[**atlasdata_controller_get_atlascoveragepoint**](GlobalAtlasServicesApi.md#atlasdata_controller_get_atlascoveragepoint) | **GET** /coverage_point/{service_id} | Check coverage at a given location
[**atlasdata_controller_get_atlasdownload_area**](GlobalAtlasServicesApi.md#atlasdata_controller_get_atlasdownload_area) | **GET** /download_area/{service_id} | Download atlas data for an area surrounding a single center-point. Data is provided for a rectangular area.
[**atlasdata_controller_get_atlasdownload_point**](GlobalAtlasServicesApi.md#atlasdata_controller_get_atlasdownload_point) | **GET** /download_point/{service_id} | Download atlas data for a single point (node). The data is provided for the nearest data-node to the point requested.
[**atlasdata_controller_get_atlasservices**](GlobalAtlasServicesApi.md#atlasdata_controller_get_atlasservices) | **GET** /datasets | List of available atlas dataset services


# **atlasdata_controller_get_atlascoveragepoint**
> bool atlasdata_controller_get_atlascoveragepoint(service_id, lat, lon)

Check coverage at a given location

### Example

* Api Key Authentication (api_key):
```python
from __future__ import print_function
import time
import emdapiglobalatlasservice
from pprint import pprint
# Defining the host is optional and defaults to http://api.emd.dk
# See configuration.py for a list of all supported configuration parameters.
configuration = emdapiglobalatlasservice.Configuration(
    host = "http://api.emd.dk"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: api_key
configuration = emdapiglobalatlasservice.Configuration(
    host = "http://api.emd.dk",
    api_key = {
        'X-Auth': 'YOUR_API_KEY'
    }
)
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-Auth'] = 'Bearer'

# Enter a context with an instance of the API client
with emdapiglobalatlasservice.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = emdapiglobalatlasservice.GlobalAtlasServicesApi(api_client)
    service_id = 'service_id_example' # str | Service_id for the dataset
    lat = 3.4 # float | Latitude for point (in decimal degrees)
    lon = 3.4 # float | Longitude for point (in decimal degrees)
    
    # example passing only required values which don't have defaults set
    try:
        # Check coverage at a given location
        api_response = api_instance.atlasdata_controller_get_atlascoveragepoint(service_id, lat, lon)
        pprint(api_response)
    except emdapiglobalatlasservice.ApiException as e:
        print("Exception when calling GlobalAtlasServicesApi->atlasdata_controller_get_atlascoveragepoint: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **service_id** | **str**| Service_id for the dataset |
 **lat** | **float**| Latitude for point (in decimal degrees) |
 **lon** | **float**| Longitude for point (in decimal degrees) |

### Return type

**bool**

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | Successful operation. |  -  |
**401** | License or token is expired. |  -  |
**403** | Forbidden - you do not have access to the requested resource. |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **atlasdata_controller_get_atlasdownload_area**
> str atlasdata_controller_get_atlasdownload_area(service_id, dataset_parameter, lat, lon, )

Download atlas data for an area surrounding a single center-point. Data is provided for a rectangular area.

### Example

* Api Key Authentication (api_key):
```python
from __future__ import print_function
import time
import emdapiglobalatlasservice
from pprint import pprint
# Defining the host is optional and defaults to http://api.emd.dk
# See configuration.py for a list of all supported configuration parameters.
configuration = emdapiglobalatlasservice.Configuration(
    host = "http://api.emd.dk"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: api_key
configuration = emdapiglobalatlasservice.Configuration(
    host = "http://api.emd.dk",
    api_key = {
        'X-Auth': 'YOUR_API_KEY'
    }
)
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-Auth'] = 'Bearer'

# Enter a context with an instance of the API client
with emdapiglobalatlasservice.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = emdapiglobalatlasservice.GlobalAtlasServicesApi(api_client)
    service_id = 'service_id_example' # str | Service_id of dataset considered
    dataset_parameter = 'dataset_parameter_example' # str | Which dataset-parameter to download
    lat = 3.4 # float | Latitude for point (decimal degrees)
    lon = 3.4 # float | Longitude for point (decimal degrees)
    data_type = 'data_type_example' # str | The data type (file type) to return from the call (check the dataset-information for valid file-extensions, e.g. netcdf, siteres and others) (optional)

    # example passing only required values which don't have defaults set
    try:
        # Download atlas data for an area surrounding a single center-point. Data is provided for a rectangular area.
        api_response = api_instance.atlasdata_controller_get_atlasdownload_area(service_id, dataset_parameter, lat, lon, )
        pprint(api_response)
    except emdapiglobalatlasservice.ApiException as e:
        print("Exception when calling GlobalAtlasServicesApi->atlasdata_controller_get_atlasdownload_area: %s\n" % e)

    # example passing only required values which don't have defaults set
    # and optional values
    try:
        # Download atlas data for an area surrounding a single center-point. Data is provided for a rectangular area.
        api_response = api_instance.atlasdata_controller_get_atlasdownload_area(service_id, dataset_parameter, lat, lon, data_type=data_type)
        pprint(api_response)
    except emdapiglobalatlasservice.ApiException as e:
        print("Exception when calling GlobalAtlasServicesApi->atlasdata_controller_get_atlasdownload_area: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **service_id** | **str**| Service_id of dataset considered |
 **dataset_parameter** | **str**| Which dataset-parameter to download |
 **lat** | **float**| Latitude for point (decimal degrees) |
 **lon** | **float**| Longitude for point (decimal degrees) |
 **width_km** | **float**| Width of the area (side of the rectangle, measured in kilometers). Default&#x3D;10. | defaults to 10
 **height_km** | **float**| Height of the area (side of the rectangle, measured in kilometers). Default&#x3D;10. | defaults to 10
 **data_type** | **str**| The data type (file type) to return from the call (check the dataset-information for valid file-extensions, e.g. netcdf, siteres and others) | [optional]

### Return type

**str**

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | Successful operation. |  -  |
**401** | License or token is expired. |  -  |
**403** | Forbidden - you do not have access to the requested resource. |  -  |
**404** | No data found, dataset-id or dataset-parameter is not found. |  -  |
**405** | Invalid filetype requested. |  -  |
**406** | Number of allowed active, parallel requests exceeded. |  -  |
**407** | Number of allowed requests in fair-use policy exceeded. |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **atlasdata_controller_get_atlasdownload_point**
> str atlasdata_controller_get_atlasdownload_point(service_id, dataset_parameter, lat, lon)

Download atlas data for a single point (node). The data is provided for the nearest data-node to the point requested.

### Example

* Api Key Authentication (api_key):
```python
from __future__ import print_function
import time
import emdapiglobalatlasservice
from pprint import pprint
# Defining the host is optional and defaults to http://api.emd.dk
# See configuration.py for a list of all supported configuration parameters.
configuration = emdapiglobalatlasservice.Configuration(
    host = "http://api.emd.dk"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: api_key
configuration = emdapiglobalatlasservice.Configuration(
    host = "http://api.emd.dk",
    api_key = {
        'X-Auth': 'YOUR_API_KEY'
    }
)
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-Auth'] = 'Bearer'

# Enter a context with an instance of the API client
with emdapiglobalatlasservice.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = emdapiglobalatlasservice.GlobalAtlasServicesApi(api_client)
    service_id = 'service_id_example' # str | Service_id of dataset considered
    dataset_parameter = 'dataset_parameter_example' # str | Which dataset-parameter to download
    lat = 3.4 # float | Latitude for point (decimal degrees)
    lon = 3.4 # float | Longitude for point (decimal degrees)
    data_type = 'data_type_example' # str | The data type (file type) to return from the call (check the dataset-information for valid file-extensions, e.g. csv, zipcsv, netcdf and others) (optional)

    # example passing only required values which don't have defaults set
    try:
        # Download atlas data for a single point (node). The data is provided for the nearest data-node to the point requested.
        api_response = api_instance.atlasdata_controller_get_atlasdownload_point(service_id, dataset_parameter, lat, lon)
        pprint(api_response)
    except emdapiglobalatlasservice.ApiException as e:
        print("Exception when calling GlobalAtlasServicesApi->atlasdata_controller_get_atlasdownload_point: %s\n" % e)

    # example passing only required values which don't have defaults set
    # and optional values
    try:
        # Download atlas data for a single point (node). The data is provided for the nearest data-node to the point requested.
        api_response = api_instance.atlasdata_controller_get_atlasdownload_point(service_id, dataset_parameter, lat, lon, data_type=data_type)
        pprint(api_response)
    except emdapiglobalatlasservice.ApiException as e:
        print("Exception when calling GlobalAtlasServicesApi->atlasdata_controller_get_atlasdownload_point: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **service_id** | **str**| Service_id of dataset considered |
 **dataset_parameter** | **str**| Which dataset-parameter to download |
 **lat** | **float**| Latitude for point (decimal degrees) |
 **lon** | **float**| Longitude for point (decimal degrees) |
 **data_type** | **str**| The data type (file type) to return from the call (check the dataset-information for valid file-extensions, e.g. csv, zipcsv, netcdf and others) | [optional]

### Return type

**str**

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | Successful operation. |  -  |
**401** | License or token is expired. |  -  |
**403** | Forbidden - you do not have access to the requested resource. |  -  |
**404** | No data found, dataset-id or dataset-parameter is not found. |  -  |
**405** | Invalid filetype requested. |  -  |
**406** | Number of allowed active, parallel requests exceeded. |  -  |
**407** | Number of allowed requests in fair-use policy exceeded. |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **atlasdata_controller_get_atlasservices**
> [atlas_service.AtlasService] atlasdata_controller_get_atlasservices()

List of available atlas dataset services

### Example

* Api Key Authentication (api_key):
```python
from __future__ import print_function
import time
import emdapiglobalatlasservice
from pprint import pprint
# Defining the host is optional and defaults to http://api.emd.dk
# See configuration.py for a list of all supported configuration parameters.
configuration = emdapiglobalatlasservice.Configuration(
    host = "http://api.emd.dk"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: api_key
configuration = emdapiglobalatlasservice.Configuration(
    host = "http://api.emd.dk",
    api_key = {
        'X-Auth': 'YOUR_API_KEY'
    }
)
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-Auth'] = 'Bearer'

# Enter a context with an instance of the API client
with emdapiglobalatlasservice.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = emdapiglobalatlasservice.GlobalAtlasServicesApi(api_client)
    
    # example, this endpoint has no required or optional parameters
    try:
        # List of available atlas dataset services
        api_response = api_instance.atlasdata_controller_get_atlasservices()
        pprint(api_response)
    except emdapiglobalatlasservice.ApiException as e:
        print("Exception when calling GlobalAtlasServicesApi->atlasdata_controller_get_atlasservices: %s\n" % e)
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**[atlas_service.AtlasService]**](AtlasService.md)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | Successful operation - list of atlas dataset returned |  -  |
**400** | No data found |  -  |
**401** | License or token is expired. |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

